@@ -26,7 +26,7 @@ from dbus.mainloop.glib import DBusGMainLoop
 
 # Would be truncated on every reboot, and shouldn't write 
 # anythong if things go right way so it is OK not to have logrotate
-log = open("/var/log/ussd-widget.log")
+log = open("/var/log/ussd-widget.log", "w")
 print >> sys.stderr, "Writing log to /var/log/ussd-widget.log"
 
 try :
@@ -393,11 +393,9 @@ class USSD_Controller:
     def callback_ussd_error(self, source, condition):
         if condition == gobject.IO_IN or condition == gobject.IO_PRI:
             self.error_message += source.read()
-            return True
         else:
             if self.error_message != "":
                 print >> log, self.error_message
-            return False
 
     def call_external_script(self, ussd_code, language):
         self.cb_reply = "";
@@ -409,12 +407,12 @@ class USSD_Controller:
                     stderr=subprocess.PIPE)
         process.stdin.close()
         gobject.io_add_watch(
-                    process.stdout, gobject.IO_IN | gobject.IO_PRI | gobject.IO_HUP | gobject.IO_ERR,
+                    p.stdout, gobject.IO_IN | gobject.IO_PRI | gobject.IO_HUP | gobject.IO_ERR,
                     self.callback_ussd_data,
                     process)
         self.error_message = "";
         gobject.io_add_watch(
-                    process.stderr, gobject.IO_IN | gobject.IO_PRI | gobject.IO_HUP | gobject.IO_ERR,
+                    p.stderr, gobject.IO_IN | gobject.IO_PRI | gobject.IO_HUP | gobject.IO_ERR,
                     self.callback_ussd_error)
 
     def ussd_renew(self, widget, event):
@@ -448,7 +446,7 @@ class USSD_Controller:
         sms_reply = self.sms_reply.strip()
         
         if reply == "" or self.config[15] and sms_reply == "" :
-            self.widget.error = 1
+                self.widget.error = 1
             self.widget.set_text (_("Error"), 5000)
             if self.retry_state == len(self.config[7]):
                 self.retry_version += 1
@@ -866,7 +864,7 @@ class UssdConfigDialog(gtk.Dialog):
             return
 
         self.font = pango.FontDescription (fontDialog.get_font_name())
-        fontDialog.destroy()
+            fontDialog.destroy()
 
     def show_box_changed (self, event):
         if self.show_box.get_active():
@@ -934,9 +932,9 @@ def smart_split_string (str, reply1, reply2, reres1 = None, reres2 = None) :
                 if word != "" :
                     result.append(word)
                     word = ""
-            else:
+            else :
                 word += str[i]
-                bs = 0 
+              bs = 0 
     
     if subst == '&':
         if reres2 != None and num != 0 and num != -1:
